"use strict";

class RPSHandler {
    constructor() {
        this.results = ["Computer Wins!", "Player Wins!", "Tie!!"];
        this.moves = [
            {
                name: "rock",
                beatBy: "paper",
                beats: "scissors",
                img: "rock.png"
            },
            {
                name: "paper",
                beatBy: "scissors",
                beats: "rock",
                img: "paper.png"
            },
            {
                name: "scissors",
                beatBy: "rock",
                beats: "paper",
                img: "scissors.png"
            }
        ];
        this.computer = null;
        this.player = null;
    }

    getComputerMove() {
        return this.moves[Math.floor(Math.random() * 3)];
    }

    handleEvent(event) {
        const infoDiv = document.querySelector(".info-div");

        if (event.type === "mouseover") {
            const move = this.moves.find(m => m.name === event.target.alt);
            infoDiv.querySelector("div:first-child > span:first-child").textContent = event.target.alt;
            infoDiv.querySelector("div:last-child > span:last-child").textContent = event.target.alt;
            infoDiv.querySelector("div:first-child > span:last-child").textContent = move.beats;
            infoDiv.querySelector("div:last-child > span:first-child").textContent = move.beatBy;
            infoDiv.classList.remove("hide");

        } else if (event.type === "mouseout") {
            infoDiv.classList.add("hide");

        } else if (event.type === "click") {
            this.player = event.target.alt;
            this.computer = this.getComputerMove();

            const compImg = document.querySelector("#computer img");
            compImg.src = `images/${this.computer.img}`;
            compImg.alt = this.computer.name;

            const resultDiv = document.querySelector(".result-div");
            let resultMessage;
            if (this.player === this.computer.name) {
                resultMessage = this.results[2];
            } else if (this.moves.find(move => move.name === this.player).beats === this.computer.name) {
                resultMessage = this.results[1];
            } else {
                resultMessage = this.results[0];
            }
            resultDiv.textContent = resultMessage;
        }
    }
}

document.addEventListener("DOMContentLoaded", () => {
    const handler = new RPSHandler();

    const imgs = document.querySelectorAll(".player img");
    for (let img of imgs) {
        img.addEventListener("mouseover", handler);
        img.addEventListener("mouseout", handler);
    }

    const buttons = document.querySelectorAll(".player button");
    for (let btn of buttons) {
        btn.addEventListener("click", handler);
    }
});
